pub trait Testable: 'static {
// Required method
fn result(&self, _: &mut Gen) -> TestResult;
}Expand description
Testable describes types (e.g., a function) whose values can be
tested.
Anything that can be tested must be capable of producing a TestResult
given a random number generator. This is trivial for types like bool,
which are just converted to either a passing or failing test result.
For functions, an implementation must generate random arguments and potentially shrink those arguments if they produce a failure.
It’s unlikely that you’ll have to implement this trait yourself.
Required Methods
fn result(&self, _: &mut Gen) -> TestResult
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".